---
title: Overriding Dependencies
description: "Resumen del capítulo 10: «Modules, Packages, and Imports» — «Versioning Your Module» — «Overriding Dependencies»."
date: 2024-03-17
last_update: 2024-03-21T11:16:14-06:00
id: 20240317111945
references:
  books:
  - book:
    - title: "Learning Go: An idiomatic approach to real-world Go programming"
    - author: Bodner, J.
    - edition: 2nd. Edition
    - publisher: O'Reilly Media
    - year: 2024
    - isbn: 9781098139292
    - bibliography: "Bodner, J. (2024). «Learning Go: An idiomatic approach to real-world Go programming». 2nd. Edition. O'Reilly Media."
  links:
  - link:
    - title:
    - date:
    - author:
    - url:
    - archive_url:
taxonomies:
  categories:
    - development
  tags:
    - golang
license: © All rights reserved
---
Forks happen. While there's a bias against forking in the open source community, sometimes a module stops being maintained or you want to experiment with changes that aren't accepted by the module's owner. A `replace` directive redirects all references to a module across all your module's dependencies and replaces them with the specified fork of the module. It looks like this:

```conf
replace github.com/jonbodner/proteus => github.com/someone/my_proteus
```

The original module location is specified on the left side of the `=>` and the replacement on the right. The right side must have a version specified, but specifying a version is optional for the left side. If a version is specified on the left side, only that specific version will be replaced. If the version is not specified, any version of the original module will be replaced with the specific version of the fork.

A `replace` directive can also refer to a path on your local filesystem:

```conf
replace github.com/jonbodner/proteus => ../projects/prot
```

With a local `replace` directive, the module version must be omitted from the right side.

> :warning: **Warning:** Avoid using local replace directives. They provided a way to modify multiple modules simultaneously before the invention of Go workspaces, but now they are a potential source of broken modules.

You also might want to block a specific version of a module from being used. Perhaps it has a bug or is incompatible with your module. Go provides the `exclude` directive to prevent a specific version of a module from being used:

```ini
exclude github.com/jonbodner/proteus v0.10.1
```

> :memo: foo

When a module version is excluded, any mentions of that module version in any dependent module are ignored. If a module version is excluded and it's the only version of that module that's required in your module's dependencies, use `go get` to add an indirect import of a different version of the module to your module's *go.mod* file so that your module still compiles.
