---
title: Retracting a Version of Your Module
description: "Resumen del capítulo 10: «Modules, Packages, and Imports» — «Versioning Your Module» — «Retracting a Version of Your Module»."
date: 2024-03-21
last_update:
id: 20240321103802
references:
  books:
  - book:
    - title: "Learning Go: An idiomatic approach to real-world Go programming"
    - author: Bodner, J.
    - edition: 2nd. Edition
    - publisher: O'Reilly Media
    - year: 2024
    - isbn: 9781098139292
    - bibliography: "Bodner, J. (2024). «Learning Go: An idiomatic approach to real-world Go programming». 2nd. Edition. O'Reilly Media."
  links:
  - link:
    - title:
    - date:
    - author:
    - url:
    - archive_url:
taxonomies:
  categories:
    - development
  tags:
    - golang
license: © All rights reserved
---
Sooner or later, you will accidentally publish a version of your module that you don't want anyone to use. Perhaps it was released by accident before testing was complete. Maybe after its release, a critical vulnerability is discovered and no one should use it any more. No matter the reason, Go provides a way for you to indicate that certain versions of a module should be ignored. This is done by adding a `retract` directive to the *go.mod* file of your module. It consists of the word `retract` and the semantic version that should no longer be used. If a range of versions shouldn't be used, you can exclude all versions in that range by placing the upper and lower bounds within brackets, separated by a comma. While it's not required, you should include a comment after a version or version range to explain the reason for the retraction.

If you wish to retract multiple nonsequential versions, you can specify them with multiple `retract` directives. In the examples shown, version 1.5.0 is excluded, as are all versions from 1.7.0 to 1.8.5, inclusive:

```conf
retract v1.5.0 // not fully tested
retract [v1.7.0, v.1.8.5] // posts your cat photos to LinkedIn w/o perm
```

Adding a `retract` directive to *go.mod* requires you to create a new version of your module. If the new version contains only the retraction, you should retract it as well.

When a version is retracted, existing builds that specified the version will continue to work, but `go get` and `go mod tidy` will not upgrade to them. They will no longer appear as options when you use the `go list` command. If the most recent version of a module is retracted, it will no longer be matched with `@latest`; the highest unretracted version will match instead.

> :memo: **Note:** While `retract` can be confused with `exclude`, there's a very important difference. You use `retract` to prevent others from using specific versions of *your* module. An `exclude` directive blocks you from using versions of another module.
